HistoryChanged class

A snapshot of the webview's navigation history state.

Constructors

HistoryChanged(bool canGoBack, bool canGoForward)
Creates a history snapshot.
const

Properties

canGoBack bool
Whether the webview can navigate back.
final
canGoForward bool
Whether the webview can navigate forward.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited