WebviewPermissionDecision enum

The reply to a browser permission request.

Inheritance
Available extensions

Values

none → const WebviewPermissionDecision

Defer to the WebView2 default behavior.

allow → const WebviewPermissionDecision

Grant the permission.

deny → const WebviewPermissionDecision

Deny the permission.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WebviewPermissionDecision>
A constant List of the values in this enum, in order of their declaration.