WebviewDownloadEvent class
A download lifecycle notification emitted on WebviewController.onDownloadEvent.
Constructors
- WebviewDownloadEvent(WebviewDownloadEventKind kind, String url, String resultFilePath, int bytesReceived, int totalBytesToReceive)
-
Creates a download event.
const
Properties
- bytesReceived → int
-
The number of bytes received so far.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → WebviewDownloadEventKind
-
The kind of download event.
final
- resultFilePath → String
-
The target file path of the download.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalBytesToReceive → int
-
The expected total number of bytes, or 0 if unknown.
final
- url → String
-
The URL the download originates from.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited