WebviewHostResourceAccessKind enum
The kind of cross origin resource access allowed for host resources of a virtual host mapping.
deny all cross origin requests are denied. allow all cross origin requests are allowed. denyCors sub resource cross origin requests are allowed, otherwise denied.
For more detailed information, please refer to Microsoft's documentation.
Values
- deny → const WebviewHostResourceAccessKind
-
All cross origin resource access is denied.
- allow → const WebviewHostResourceAccessKind
-
All cross origin resource access is allowed.
- denyCors → const WebviewHostResourceAccessKind
-
Cross origin resource access is allowed for sub resources, denied otherwise.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WebviewHostResourceAccessKind> - A constant List of the values in this enum, in order of their declaration.